coverde library
Coverde CLI package.
Classes
- CheckCommand
- A command to check the minimum coverage value from a trace file.
- CovComputable
- Computable Coverage Entity
- CovDir
- Covered Directory
- CovElement
- Coverage Filesystem Element
- CoverdeCommand
- A base coverde command.
- CoverdeCommandParams
- The parameters for a CoverdeCommand.
- CoverdeCommandRunner
- The runner for the coverde command.
- CovFile
- Covered File Data
- CovLine
- Covered Line Data
- FileLineCoverageDetails
- A line of code with its coverage status.
- FilterCommand
- A command to filter coverage info files.
- OptimizeTestsCommand
- A subcommand to optimize tests.
- PackageVersioningInfo
- Information about the versioning of a package.
- PackageVersionManager
- A manager for checking and updating the version of a package.
- PackageVersionManagerDependencies
- Dependencies for a PackageVersionManager.
- ReportCommand
- A command to generate the coverage report from a given trace file.
- RmCommand
- A generic subcommand to remove a set of files and/or folders.
- TraceFile
- Trace File Data
- ValueCommand
- A command to compute the coverage of a given info file.
Enums
- CoverdeFilterDirectoryOperation
- An operation on a directory.
- CoverdeFilterFileOperation
- An operation on a file.
- CoverdeOptimizeTestsDirectoryOperation
- An operation on a directory.
- CoverdeOptimizeTestsFileOperation
- An operation on a file.
- CoverdeReportFileOperation
- An operation on a file.
- CoverdeRmDirectoryOperation
- An operation on a directory.
- CoverdeRmFileOperation
- An operation on a file.
- FileCoverageLogLevel
- The log level for the coverage value for each source file listed in the trace file.
- FileLineCoverageStatus
- The coverage status of a line of code.
- GenerateHtmlCoverageReportFileOperation
- An operation on a file.
- UpdateCheckMode
- The mode for the update check.
Extensions
- CoverageValue on T
- Extension on a coverage num value to validate it.
- PackageVersionManagerLogger on Logger
- Extension for logging PackageVersionManager failures.
Constants
-
fileReportLineTemplateHtmlBytes
→ const List<
int> -
The collection of bytes that represent the content of the
file_report_line_template.htmlasset. - fileReportLineTemplateHtmlFilename → const String
-
The filename of the
file_report_line_template.htmlasset -
fileReportTemplateHtmlBytes
→ const List<
int> -
The collection of bytes that represent the content of the
file_report_template.htmlasset. - fileReportTemplateHtmlFilename → const String
-
The filename of the
file_report_template.htmlasset -
folderReportRowTemplateHtmlBytes
→ const List<
int> -
The collection of bytes that represent the content of the
folder_report_row_template.htmlasset. - folderReportRowTemplateHtmlFilename → const String
-
The filename of the
folder_report_row_template.htmlasset -
folderReportTemplateHtmlBytes
→ const List<
int> -
The collection of bytes that represent the content of the
folder_report_template.htmlasset. - folderReportTemplateHtmlFilename → const String
-
The filename of the
folder_report_template.htmlasset -
launchCommands
→ const Map<
String, String> - The commands to launch the browser on different platforms.
- packageName → const String
- Package name.
-
reportStyleCssBytes
→ const List<
int> -
The collection of bytes that represent the content of the
report_style.cssasset. - reportStyleCssFilename → const String
-
The filename of the
report_style.cssasset -
sortAlphaPngBytes
→ const List<
int> -
The collection of bytes that represent the content of the
sort_alpha.pngasset. - sortAlphaPngFilename → const String
-
The filename of the
sort_alpha.pngasset -
sortNumericPngBytes
→ const List<
int> -
The collection of bytes that represent the content of the
sort_numeric.pngasset. - sortNumericPngFilename → const String
-
The filename of the
sort_numeric.pngasset
Properties
- debugOperatingSystemIdentifier ↔ String?
-
The overridden operating system identifier for debugging purposes.
getter/setter pair
- isDebugMode → bool
-
Whether the current execution mode is debug.
no setter
- operatingSystemIdentifier → String
-
The operating system identifier of the current machine.
no setter
Functions
-
coverde(
{required List< String> args, required Logger logger, required String globalLockFilePath, required String pubApiBaseUrl, required Client httpClient, required String rawDartVersion}) → Future<void> - The command invocation function that provides test execution optimization and coverage trace file manipulation.
Exceptions / Errors
- AbsentGlobalLockFileForGlobalInstallationFailure
- A failure that occurs when the global lock file is absent.
- CoverdeCheckCoverageBelowMinimumFailure
- A CheckCommand failure that indicates that the coverage value is below the minimum coverage threshold.
- CoverdeCheckEmptyTraceFileFailure
- A CheckCommand failure that indicates that the trace file is empty.
- CoverdeCheckFailure
- The interface for CheckCommand failures.
- CoverdeCheckInvalidInputFailure
- The interface for CheckCommand failures that indicates that an invalid input was provided.
- CoverdeCheckInvalidMinimumCoverageThresholdFailure
- A CheckCommand failure that indicates that the minimum coverage threshold was provided but is invalid.
- CoverdeCheckInvalidTraceFileFailure
- The interface for CheckCommand failures that indicates that an invalid trace file was provided.
- CoverdeCheckMissingMinimumCoverageThresholdFailure
- A CheckCommand failure that indicates that the minimum coverage threshold was not provided.
- CoverdeCheckMoreThanOneArgumentFailure
- A CheckCommand failure that indicates that more than one argument was provided.
- CoverdeCheckTraceFileNotFoundFailure
- A CheckCommand failure that indicates that the trace file was not found.
- CoverdeCheckTraceFileReadFailure
- A CheckCommand failure that indicates that a trace file read operation failed.
- CoverdeFailure
-
The interface for
coverdefailures. - CoverdeFilterDirectoryCreateFailure
- A FilterCommand failure that indicates that a directory creation operation failed.
- CoverdeFilterDirectoryOperationFailure
- The interface for FilterCommand failures that indicates that a file system operation on a directory failed.
- CoverdeFilterFailure
- The interface for FilterCommand failures.
- CoverdeFilterFileOperationFailure
- The interface for FilterCommand failures that indicates that a file system operation on a file failed.
- CoverdeFilterFileWriteFailure
- A FilterCommand failure that indicates that a file write operation failed.
- CoverdeFilterInvalidInputFailure
- The interface for FilterCommand failures that indicates that an invalid input was provided.
- CoverdeFilterInvalidRegexPatternFailure
- A FilterCommand failure that indicates that an invalid regex pattern was provided.
- CoverdeFilterTraceFileNotFoundFailure
- A FilterCommand failure that indicates that the trace file was not found.
- CoverdeFilterTraceFileReadFailure
- A FilterCommand failure that indicates that a trace file read operation failed.
- CoverdeGetGlobalPackageInstallationInfoFailure
- A failure that occurs when retrieving the global package installation info fails.
- CoverdeGetRemotePackageVersioningInfosFailure
- A failure that occurs when retrieving the remote package versioning infos fails.
- CoverdeOptimizeTestsDirectoryCreateFailure
- A OptimizeTestsCommand failure that indicates that a directory creation operation failed.
- CoverdeOptimizeTestsDirectoryListFailure
- A OptimizeTestsCommand failure that indicates that a directory listing operation failed.
- CoverdeOptimizeTestsDirectoryOperationFailure
- The interface for OptimizeTestsCommand failures that indicates that a file system operation on a directory failed.
- CoverdeOptimizeTestsFailure
- The interface for OptimizeTestsCommand failures.
- CoverdeOptimizeTestsFileDeleteFailure
- A OptimizeTestsCommand failure that indicates that a file deletion operation failed.
- CoverdeOptimizeTestsFileOperationFailure
- The interface for OptimizeTestsCommand failures that indicates that a file system operation on a file failed.
- CoverdeOptimizeTestsFileReadFailure
- A OptimizeTestsCommand failure that indicates that a file read operation failed.
- CoverdeOptimizeTestsFileWriteFailure
- A OptimizeTestsCommand failure that indicates that a file write operation failed.
- CoverdeOptimizeTestsInvalidInputFailure
- The interface for OptimizeTestsCommand failures that indicates that an invalid input was provided.
- CoverdeOptimizeTestsPubspecNotFoundFailure
- A OptimizeTestsCommand failure that indicates that the pubspec.yaml file was not found.
- CoverdeReportEmptyTraceFileFailure
- A ReportCommand failure that indicates that the trace file is empty.
- CoverdeReportFailure
- The interface for ReportCommand failures.
- CoverdeReportFileCreateFailure
- A ReportCommand failure that indicates that a file creation operation failed.
- CoverdeReportFileOperationFailure
- The interface for ReportCommand failures that indicates that a file system operation on a file failed.
- CoverdeReportFileReadFailure
- A ReportCommand failure that indicates that a file read operation failed.
- CoverdeReportFileWriteFailure
- A ReportCommand failure that indicates that a file write operation failed.
- CoverdeReportInvalidHighThresholdFailure
- A ReportCommand failure that indicates that an invalid high threshold was provided.
- CoverdeReportInvalidInputFailure
- The interface for ReportCommand failures that indicates that an invalid input was provided.
- CoverdeReportInvalidMediumThresholdFailure
- A ReportCommand failure that indicates that an invalid medium threshold was provided.
- CoverdeReportInvalidThresholdRelationshipFailure
- A ReportCommand failure that indicates that the threshold relationship is invalid (medium >= high).
- CoverdeReportInvalidTraceFileFailure
- The interface for ReportCommand failures that indicates that an invalid trace file was provided.
- CoverdeReportTraceFileNotFoundFailure
- A ReportCommand failure that indicates that the trace file was not found.
- CoverdeReportTraceFileReadFailure
- A ReportCommand failure that indicates that a trace file read operation failed.
- CoverdeRmDirectoryDeleteFailure
- A RmCommand failure that indicates that a directory deletion operation failed.
- CoverdeRmDirectoryOperationFailure
- The interface for RmCommand failures that indicates that a file system operation on a directory failed.
- CoverdeRmElementNotFoundFailure
- A RmCommand failure that indicates that an element was not found when absence is not accepted.
- CoverdeRmFailure
- The interface for RmCommand failures.
- CoverdeRmFileDeleteFailure
- A RmCommand failure that indicates that a file deletion operation failed.
- CoverdeRmFileOperationFailure
- The interface for RmCommand failures that indicates that a file system operation on a file failed.
- CoverdeRmInvalidInputFailure
- The interface for RmCommand failures that indicates that an invalid input was provided.
- CoverdeRmMissingPathsFailure
- A RmCommand failure that indicates that no paths were provided.
- CoverdeValueEmptyTraceFileFailure
- A ValueCommand failure that indicates that the trace file is empty.
- CoverdeValueFailure
- The interface for ValueCommand failures.
- CoverdeValueFileReadFailure
- A ValueCommand failure that indicates that a file read operation failed.
- CoverdeValueInvalidTraceFileFailure
- The interface for ValueCommand failures that indicates that an invalid trace file was provided.
- CoverdeValueTraceFileNotFoundFailure
- A ValueCommand failure that indicates that the trace file was not found.
- CoverdeValueTraceFileReadFailure
- A ValueCommand failure that indicates that a trace file read operation failed.
- CovFileFormatFailure
- A CoverdeFailure that indicates that the coverage data of a given tested file is not properly formatted.
- GenerateHtmlCoverageReportFailure
- The interface for a failure that occurs when generating an HTML coverage report.
- GenerateHtmlCoverageReportFileCreateFailure
- The interface for a failure that occurs when creating a file during HTML coverage report generation.
- GenerateHtmlCoverageReportFileOperationFailure
- The interface for a failure that occurs when performing a file operation during HTML coverage report generation.
- GenerateHtmlCoverageReportFileReadFailure
- The interface for a failure that occurs when reading a file during HTML coverage report generation.
- GenerateHtmlCoverageReportFileWriteFailure
- The interface for a failure that occurs when writing to a file during HTML coverage report generation.
- InvalidGlobalLockFileContentForGlobalInstallationFailure
- A failure that occurs when the global lock file is invalid.
- InvalidGlobalLockFileYamlForGlobalInstallationFailure
- A failure that occurs when the global lock file is invalid.
- InvalidGlobalLockMemberTypeForGlobalInstallationFailure
- A failure that occurs when the global lock member is not of the expected type.
- InvalidGlobalLockMemberValueForGlobalInstallationFailure
- A failure that occurs when the global lock member value is invalid.
- InvalidRemotePackageVersioningInfoFailure
- A failure that occurs when the remote package versioning info is invalid.
- InvalidRemotePackageVersioningInfoMemberTypeFailure
- A failure that occurs when the remote package versioning info member is not of the expected type.
- InvalidRemotePackageVersioningInfoMemberValueFailure
- A failure that occurs when the remote package versioning info member value is invalid.
- NoDirectMainHostedPackageForGlobalInstallationFailure
- A failure that occurs when the global lock file does not contain a direct main hosted package within its registered packages.
- UnexpectedRemotePackageVersioningInfosRetrievalFailure
- A failure that occurs when the remote package versioning infos retrieval fails.
- UnreadableGlobalLockFileForGlobalInstallationFailure
- A failure that occurs when the global lock file is unreadable.